@@ -208,6 +208,10 @@ Client::Client(Workspace* ws)
  */
 Client::~Client()
 {
+    if (m_killHelperPID && !::kill(m_killHelperPID, 0)) { // means the process is alive
+        ::kill(m_killHelperPID, SIGTERM);
+        m_killHelperPID = 0;
+    }
     //SWrapper::Client::clientRelease(this);
 #ifdef HAVE_XSYNC
     if (syncRequest.alarm != None)
@@ -1210,21 +1214,25 @@ void Client::updateVisibility()
             internalHide(Allowed);
         return;
     }
-    if( workspace()->showingDesktop()) {
-        bool belongs_to_desktop = false;
-        for (ClientList::ConstIterator it = group()->members().constBegin();
-                it != group()->members().constEnd();
-                ++it)
-            if ((*it)->isDesktop()) {
-                belongs_to_desktop = true;
-                break;
-            }
-        if (!belongs_to_desktop)
-            workspace()->resetShowingDesktop(true);
-    }
+    resetShowingDesktop(true);
     internalShow(Allowed);
 }
 
+
+void Client::resetShowingDesktop(bool keep_hidden)
+{
+    if (isDock() || !workspace()->showingDesktop())
+        return;
+    bool belongs_to_desktop = false;
+    for (ClientList::ConstIterator it = group()->members().constBegin(),
+                                    end = group()->members().constEnd(); it != end; ++it)
+        if ((belongs_to_desktop == (*it)->isDesktop()))
+            break;
+
+    if (!belongs_to_desktop)
+        workspace()->resetShowingDesktop(keep_hidden);
+}
+
 /**
  * Sets the client window's mapping state. Possible values are
  * WithdrawnState, IconicState, NormalState.
@@ -1940,11 +1948,35 @@ bool Client::tabTo(Client *other, bool behind, bool activate)
 bool Client::untab(const QRect &toGeometry)
 {
     TabGroup *group = tab_group;
-    if (group && group->remove(this, toGeometry)) { // remove sets the tabgroup to "0", therefore the pointer is cached
+    if (group && group->remove(this)) { // remove sets the tabgroup to "0", therefore the pointer is cached
         if (group->isEmpty()) {
             delete group;
         }
         setClientShown(!(isMinimized() || isShade()));
+        bool keepSize = toGeometry.size() == size();
+        bool changedSize = false;
+        if (quickTileMode() != QuickTileNone) {
+            changedSize = true;
+            setQuickTileMode(QuickTileNone); // if we leave a quicktiled group, assume that the user wants to untile
+        }
+        if (toGeometry.isValid()) {
+            if (maximizeMode() != Client::MaximizeRestore) {
+                changedSize = true;
+                maximize(Client::MaximizeRestore); // explicitly calling for a geometry -> unmaximize
+            }
+            if (keepSize && changedSize) {
+                geom_restore = geometry(); // checkWorkspacePosition() invokes it
+                QPoint cpoint = QCursor::pos();
+                QPoint point = cpoint;
+                point.setX((point.x() - toGeometry.x()) * geom_restore.width() / toGeometry.width());
+                point.setY((point.y() - toGeometry.y()) * geom_restore.height() / toGeometry.height());
+                geom_restore.moveTo(cpoint-point);
+            } else {
+                geom_restore = toGeometry; // checkWorkspacePosition() invokes it
+            }
+            setGeometry(geom_restore);
+            checkWorkspacePosition();
+        }
         return true;
     }
     return false;
@@ -2201,6 +2233,8 @@ void Client::getSyncCounter()
 void Client::sendSyncRequest()
 {
 #ifdef HAVE_XSYNC
+    delete m_readyForPaintingTimer;
+    m_readyForPaintingTimer = 0;
     if (syncRequest.counter == None || syncRequest.isPending)
         return; // do NOT, NEVER send a sync request when there's one on the stack. the clients will just stop respoding. FOREVER! ...
 
