@@ -407,12 +407,6 @@ void EffectsHandlerImpl::slotClientAdded(Client *c)
         connect(c, SIGNAL(windowShown(KWin::Toplevel*)), SLOT(slotClientShown(KWin::Toplevel*)));
 }
 
-void EffectsHandlerImpl::slotUnmanagedAdded(Unmanaged *u)
-{   // regardless, unmanaged windows are -yet?- not synced anyway
-    setupUnmanagedConnections(u);
-    emit windowAdded(u->effectWindow());
-}
-
 void EffectsHandlerImpl::slotClientShown(KWin::Toplevel *t)
 {
     Q_ASSERT(dynamic_cast<Client*>(t));
@@ -422,6 +416,22 @@ void EffectsHandlerImpl::slotClientShown(KWin::Toplevel *t)
         emit windowAdded(c->effectWindow());
 }
 
+void EffectsHandlerImpl::slotUnmanagedAdded(Unmanaged *u)
+{
+    if (u->readyForPainting())
+        slotUnmanagedShown(u);
+    else
+        connect(u, SIGNAL(windowShown(KWin::Toplevel*)), SLOT(slotUnmanagedShown(KWin::Toplevel*)));
+}
+
+void EffectsHandlerImpl::slotUnmanagedShown(KWin::Toplevel *t)
+{
+    Q_ASSERT(dynamic_cast<Unmanaged*>(t));
+    Unmanaged *u = static_cast<Unmanaged*>(t);
+    setupUnmanagedConnections(u);
+    emit windowAdded(u->effectWindow());
+}
+
 void EffectsHandlerImpl::slotDeletedRemoved(KWin::Deleted *d)
 {
     emit windowDeleted(d->effectWindow());
@@ -1325,9 +1335,9 @@ void EffectsHandlerImpl::reconfigureEffect(const QString& name)
         }
 }
 
-bool EffectsHandlerImpl::isEffectLoaded(const QString& name)
+bool EffectsHandlerImpl::isEffectLoaded(const QString& name) const
 {
-    for (QVector< EffectPair >::iterator it = loaded_effects.begin(); it != loaded_effects.end(); ++it)
+    for (QVector< EffectPair >::const_iterator it = loaded_effects.constBegin(); it != loaded_effects.constEnd(); ++it)
         if ((*it).first == name)
             return true;
 
@@ -1396,6 +1406,28 @@ void EffectsHandlerImpl::slotHideOutline()
     emit hideOutline();
 }
 
+QString EffectsHandlerImpl::supportInformation(const QString &name) const
+{
+    if (!isEffectLoaded(name)) {
+        return QString();
+    }
+    for (QVector< EffectPair >::const_iterator it = loaded_effects.constBegin(); it != loaded_effects.constEnd(); ++it) {
+        if ((*it).first == name) {
+            QString support((*it).first + ":\n");
+            const QMetaObject *metaOptions = (*it).second->metaObject();
+            for (int i=0; i<metaOptions->propertyCount(); ++i) {
+                const QMetaProperty property = metaOptions->property(i);
+                if (QLatin1String(property.name()) == "objectName") {
+                    continue;
+                }
+                support.append(QLatin1String(property.name()) % ": " % (*it).second->property(property.name()).toString() % '\n');
+            }
+            return support;
+        }
+    }
+    return QString();
+}
+
 //****************************************
 // EffectWindowImpl
 //****************************************
