@@ -57,12 +57,12 @@ BoxSwitchEffect::BoxSwitchEffect()
 
     highlight_margin = 10;
     reconfigure(ReconfigureAll);
-    connect(effects, SIGNAL(windowClosed(EffectWindow*)), this, SLOT(slotWindowClosed(EffectWindow*)));
+    connect(effects, SIGNAL(windowClosed(KWin::EffectWindow*)), this, SLOT(slotWindowClosed(KWin::EffectWindow*)));
     connect(effects, SIGNAL(tabBoxAdded(int)), this, SLOT(slotTabBoxAdded(int)));
     connect(effects, SIGNAL(tabBoxClosed()), this, SLOT(slotTabBoxClosed()));
     connect(effects, SIGNAL(tabBoxUpdated()), this, SLOT(slotTabBoxUpdated()));
-    connect(effects, SIGNAL(windowGeometryShapeChanged(EffectWindow*,QRect)), this, SLOT(slotWindowGeometryShapeChanged(EffectWindow*,QRect)));
-    connect(effects, SIGNAL(windowDamaged(EffectWindow*,QRect)), this, SLOT(slotWindowDamaged(EffectWindow*,QRect)));
+    connect(effects, SIGNAL(windowGeometryShapeChanged(KWin::EffectWindow*,QRect)), this, SLOT(slotWindowGeometryShapeChanged(KWin::EffectWindow*,QRect)));
+    connect(effects, SIGNAL(windowDamaged(KWin::EffectWindow*,QRect)), this, SLOT(slotWindowDamaged(KWin::EffectWindow*,QRect)));
 }
 
 BoxSwitchEffect::~BoxSwitchEffect()
@@ -96,7 +96,7 @@ void BoxSwitchEffect::prePaintWindow(EffectWindow* w, WindowPrePaintData& data,
         if (mMode == TabBoxWindowsMode || mMode == TabBoxWindowsAlternativeMode) {
             if (windows.contains(w)) {
                 if (w == selected_window)
-                    w->enablePainting(EffectWindow::PAINT_DISABLED_BY_CLIENT_GROUP);
+                    w->enablePainting(EffectWindow::PAINT_DISABLED_BY_TAB_GROUP);
                 else
                     data.setTranslucent();
                 w->enablePainting(EffectWindow::PAINT_DISABLED_BY_MINIMIZE | EffectWindow::PAINT_DISABLED_BY_DESKTOP);
