@@ -107,10 +107,8 @@ void MouseMarkEffect::paintScreen(int mask, QRegion region, ScreenPaintData& dat
     effects->paintScreen(mask, region, data);   // paint normal screen
     if (marks.isEmpty() && drawing.isEmpty())
         return;
-#ifdef KWIN_HAVE_OPENGL
     if ( effects->compositingType() == OpenGLCompositing) {
 #ifndef KWIN_HAVE_OPENGLES
-        glPushAttrib(GL_ENABLE_BIT | GL_CURRENT_BIT | GL_LINE_BIT);
         glEnable(GL_LINE_SMOOTH);
 #endif
         glLineWidth(width);
@@ -144,12 +142,10 @@ void MouseMarkEffect::paintScreen(int mask, QRegion region, ScreenPaintData& dat
             ShaderManager::instance()->popShader();
         }
         glLineWidth(1.0);
-#ifndef KWIN_HAVE_OPENGLES
+    #ifndef KWIN_HAVE_OPENGLES
         glDisable(GL_LINE_SMOOTH);
-        glPopAttrib();
-#endif
+    #endif
     }
-#endif
 #ifdef KWIN_HAVE_XRENDER_COMPOSITING
     if ( effects->compositingType() == XRenderCompositing) {
         XRenderColor c = preMultiply(color);
