@@ -58,6 +58,15 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #define GL_FRAMEBUFFER_COMPLETE GL_FRAMEBUFFER_COMPLETE_EXT
 #endif
 
+#ifndef GL_DRAW_FRAMEBUFFER
+#define GL_DRAW_FRAMEBUFFER               0x8CA9
+#endif
+
+#ifndef GL_READ_FRAMEBUFFER
+#define GL_READ_FRAMEBUFFER               0x8CA8
+#endif
+
+
 #include <fixx11h.h>
 
 namespace KWin
@@ -188,8 +197,10 @@ extern KWIN_EXPORT glXCopySubBuffer_func glXCopySubBuffer;
 // video_sync extension functions
 typedef int (*glXGetVideoSync_func)(unsigned int *count);
 typedef int (*glXWaitVideoSync_func)(int divisor, int remainder, unsigned int *count);
+typedef int (*glXSwapInterval_func)(int ratio);
 extern KWIN_EXPORT glXGetVideoSync_func glXGetVideoSync;
 extern KWIN_EXPORT glXWaitVideoSync_func glXWaitVideoSync;
+extern KWIN_EXPORT glXSwapInterval_func glXSwapInterval;
 // GLX_SGIX_fbconfig and misc GLX 1.3 stuff
 typedef int (*glXGetFBConfigAttrib_func)(Display *dpy, GLXFBConfig config,
         int attribute, int *value);
