@@ -42,10 +42,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QMessageBox>
 #include <QEvent>
 
-#ifdef KWIN_BUILD_SCRIPTING
-#include "scripting/scripting.h"
-#endif
-
 #include <kdialog.h>
 #include <kstandarddirs.h>
 #include <kdebug.h>
@@ -53,7 +49,16 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QLabel>
 #include <KComboBox>
 #include <QVBoxLayout>
-#include <kworkspace/kworkspace.h>
+
+#include "config-workspace.h"
+
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif // HAVE_UNISTD_H
+
+#ifdef HAVE_MALLOC_H
+#include <malloc.h>
+#endif // HAVE_MALLOC_H
 
 #include <ksmserver_interface.h>
 
@@ -218,7 +223,7 @@ public:
         addWM("metacity");
         addWM("openbox");
         addWM("fvwm2");
-        addWM("kwin");
+        addWM(KWIN_NAME);
 
         setMainWidget(mainWidget);
 
@@ -273,7 +278,7 @@ Application::Application()
     if (crashes >= 4) {
         // Something has gone seriously wrong
         AlternativeWMDialog dialog;
-        QString cmd = "kwin";
+        QString cmd = KWIN_NAME;
         if (dialog.exec() == QDialog::Accepted)
             cmd = dialog.selectedWM();
         else
@@ -297,10 +302,9 @@ Application::Application()
     // Reset crashes count if we stay up for more that 15 seconds
     QTimer::singleShot(15 * 1000, this, SLOT(resetCrashesCount()));
 
-    // If KWin was already running it saved its configuration after loosing the selection -> Reread
-    config->reparseConfiguration();
-
     initting = true; // Startup...
+    // first load options - done internally by a different thread
+    options = new Options;
 
     // Install X11 error handler
     XSetErrorHandler(x11ErrorHandler);
@@ -316,7 +320,6 @@ Application::Application()
     // This tries to detect compositing options and can use GLX. GLX problems
     // (X errors) shouldn't cause kwin to abort, so this is out of the
     // critical startup section where x errors cause kwin to abort.
-    options = new Options;
 
     // create workspace.
     (void) new Workspace(isSessionRestored());
@@ -407,7 +410,20 @@ KDE_EXPORT int kdemain(int argc, char * argv[])
         }
     }
 
-    KWorkSpace::trimMalloc();
+#ifdef M_TRIM_THRESHOLD
+    // Prevent fragmentation of the heap by malloc (glibc).
+    //
+    // The default threshold is 128*1024, which can result in a large memory usage
+    // due to fragmentation especially if we use the raster graphicssystem. On the
+    // otherside if the threshold is too low, free() starts to permanently ask the kernel
+    // about shrinking the heap.
+#ifdef HAVE_UNISTD_H
+    const int pagesize = sysconf(_SC_PAGESIZE);
+#else
+    const int pagesize = 4*1024;
+#endif // HAVE_UNISTD_H
+    mallopt(M_TRIM_THRESHOLD, 5*pagesize);
+#endif // M_TRIM_THRESHOLD
 
     // the raster graphicssystem has a quite terrible performance on the XRender backend or when not
     // compositing at all while some to many decorations suffer from bad performance of the native
@@ -419,7 +435,7 @@ KDE_EXPORT int kdemain(int argc, char * argv[])
     // ""known to be stupid" ideas ;-P
     // The invalid system parameter "" will use the systems default graphicssystem
     // "!= XRender" is intended since eg. pot. SW backends likely would profit from raster as well
-    KConfigGroup config(KSharedConfig::openConfig("kwinrc"), "Compositing");
+    KConfigGroup config(KSharedConfig::openConfig(KWIN_CONFIG), "Compositing");
     QString preferredSystem("native");
     if (config.readEntry("Enabled", true) && config.readEntry("Backend", "OpenGL") != "XRender")
         preferredSystem = "";
@@ -468,7 +484,7 @@ KDE_EXPORT int kdemain(int argc, char * argv[])
     }
 
     KAboutData aboutData(
-        "kwin",                     // The program name used internally
+        KWIN_NAME,                     // The program name used internally
         0,                          // The message catalog name. If null, program name is used instead
         ki18n("KWin"),              // A displayable program name string
         version,                    // The program version string
@@ -487,9 +503,6 @@ KDE_EXPORT int kdemain(int argc, char * argv[])
     args.add("lock", ki18n("Disable configuration options"));
     args.add("replace", ki18n("Replace already-running ICCCM2.0-compliant window manager"));
     args.add("crashes <n>", ki18n("Indicate that KWin has recently crashed n times"));
-#ifdef KWIN_BUILD_SCRIPTING
-    args.add("noscript", ki18n("Load the script testing dialog"));
-#endif
     KCmdLineArgs::addCmdLineOptions(args);
 
     if (KDE_signal(SIGTERM, KWin::sighandler) == SIG_IGN)
@@ -499,21 +512,15 @@ KDE_EXPORT int kdemain(int argc, char * argv[])
     if (KDE_signal(SIGHUP, KWin::sighandler) == SIG_IGN)
         KDE_signal(SIGHUP, SIG_IGN);
 
-    // HACK: this is needed to work around a Qt4.4.0RC1 bug (#157659)
-    setenv("QT_SLOW_TOPLEVEL_RESIZE", "1", true);
-
     // Disable the glib event loop integration, since it seems to be responsible
     // for several bug reports about high CPU usage (bug #239963)
     setenv("QT_NO_GLIB", "1", true);
 
     org::kde::KSMServerInterface ksmserver("org.kde.ksmserver", "/KSMServer", QDBusConnection::sessionBus());
-    ksmserver.suspendStartup("kwin");
+    ksmserver.suspendStartup(KWIN_NAME);
     KWin::Application a;
-#ifdef KWIN_BUILD_SCRIPTING
-    KWin::Scripting scripting;
-#endif
 
-    ksmserver.resumeStartup("kwin");
+    ksmserver.resumeStartup(KWIN_NAME);
     KWin::SessionManager weAreIndeed;
     KWin::SessionSaveDoneHelper helper;
     KGlobal::locale()->insertCatalog("kwin_effects");
@@ -534,9 +541,6 @@ KDE_EXPORT int kdemain(int argc, char * argv[])
         appname, QDBusConnectionInterface::DontQueueService);
 
     KCmdLineArgs* sargs = KCmdLineArgs::parsedArgs();
-#ifdef KWIN_BUILD_SCRIPTING
-    scripting.start();
-#endif
 
     return a.exec();
 }
