@@ -111,6 +111,14 @@ public:
     * @return The next TabBoxClient in focus chain
     */
     virtual QWeakPointer<TabBoxClient> nextClientFocusChain(TabBoxClient* client) const = 0;
+    /**
+     * This method is used by the ClientModel to find an entrance into the focus chain in case
+     * there is no active Client.
+     *
+     * @return The first Client of the focus chain
+     * @since 4.9.1
+     **/
+    virtual QWeakPointer<TabBoxClient> firstClientFocusChain() const = 0;
     /**
     * @param client The client whose desktop name should be retrieved
     * @return The desktop name of the given TabBoxClient. If the client is
