@@ -33,6 +33,13 @@ private slots:
      * See bug #303840
      **/
     void testLongestCaptionWithNullClient();
+    /**
+     * Tests the creation of the Client list for the case that
+     * there is no active Client, but that Clients actually exist.
+     *
+     * See BUG: 305449
+     **/
+    void testCreateClientListNoActiveClient();
 };
 
 #endif
