@@ -37,6 +37,25 @@ public slots:
 
 private:
     void init();
+    /**
+     * For older kernels that doesn't indicate which type the interface use we have
+     * a whitelsit based on the feedback given by our users, if the interface is not
+     * within our whitelist we will look for a random one within the backlight folder
+     */
+    void initUsingWhitelist();
+
+    /**
+     * The kernel offer from version 2.6.37 the type of the interface, and based on that
+     * we can decide which interface is better for us, being the order
+     * firmware-platform-raw
+     */
+    void initUsingBacklightType();
+
+    /**
+     * If Kernel older than 2.6.37 use whitelsit, otherwise use backlight/type
+     * @see https://bugs.kde.org/show_bug.cgi?id=288180
+     */
+    bool useWhitelistInit();
     int maxBrightness() const;
     bool m_isSupported;
     QString m_dirname;
